API Documentation
#################

Core
======

.. automodule:: pyclesperanto._core
    :members:
    :undoc-members:

Memory management
=================

.. automodule:: pyclesperanto._memory
    :members:
    :undoc-members:

Data structure
==============

.. automodule:: pyclesperanto._array
    :members:
    :undoc-members:

.. automodule:: pyclesperanto._operators
    :members:
    :undoc-members:

Functionalities
==============

.. automodule:: pyclesperanto._functionalities
    :members:
    :undoc-members:

Filters
=======

.. automodule:: pyclesperanto._tier1
   :members:
   :undoc-members:
   :imported-members: 
   :exclude-members: Image, Device, _Array, plugin_function

.. automodule:: pyclesperanto._tier2
    :members:
    :undoc-members:
    :imported-members:
    :exclude-members: Image, Device, _Array, plugin_function

.. automodule:: pyclesperanto._tier3
    :members:
    :undoc-members:
    :imported-members:
    :exclude-members: Image, Device, _Array, plugin_function

.. automodule:: pyclesperanto._tier4
    :members:
    :undoc-members:
    :imported-members:
    :exclude-members: Image, Device, _Array, plugin_function

.. automodule:: pyclesperanto._tier5
    :members:
    :undoc-members:
    :imported-members:
    :exclude-members: Image, Device, _Array, plugin_function

.. automodule:: pyclesperanto._tier6
    :members:
    :undoc-members:
    :imported-members:
    :exclude-members: Image, Device, _Array, plugin_function

.. automodule:: pyclesperanto._tier7
    :members:
    :undoc-members:
    :imported-members:
    :exclude-members: Image, Device, _Array, plugin_function
